==> coupon-facade-1.5.1-vg-20221215.081313-7-sources.jar: com/bizvane/couponfacade/enums/SendTypeEnum.java <==
package com.bizvane.couponfacade.enums;

/**
 * 券实例发放类型枚举类
 * Created by yunjie.tian on 2018/8/9.
 */
public enum SendTypeEnum {

    //会员生日
    SEND_COUPON_BIRTH("15","会员生日"),
    //受赠
    SEND_COUPON_GIVE("20","受赠"),
    //积分兑换
    SEND_COUPON_INTEGRAL("25","积分兑换"),
    //SEND_COUPON_ONLINE_ACTIVITY("30","线上开卡"),
    //会员升级
    SEND_COUPON_UPGRADE_ACTIVITY("35","会员升级"),
    //SEND_COUPON_BIRTH_ACTIVITY("40","会员生日"),
    //会员消费
    SEND_COUPON_COUSUME_ACTIVITY("45","会员消费"),
    //会员签到
    SEND_COUPON_SIGN_ACTIVITY("50","会员签到"),
    //领券
    SEND_COUPON_RECEIVE_ACTIVITY("55","领券"),
    //社交活动
    SEND_COUPON_SOCIAL_ACTIVITY ("56","社交活动"),
    //完善资料
    SEND_COUPON_INFORM_TASK("60","完善资料"),
    //微信分享
    SEND_COUPON_WX_SHARE_TASK("65","微信分享"),
    //消费次数
    SEND_COUPON_COUSUME_TIMES_TASK("70","消费次数"),
    //消费金额
    SEND_COUPON_COUSUME_MONEY_TASK("75","消费金额"),
    //邀请开卡
    SEND_COUPON_INVITE_OPENCARD_TASK("80","邀请开卡"),
    //调查问卷
    SEND_COUPON_QUESTIONNAIRE_TASK("81","调查问卷"),
    //手动发券
    SEND_COUPON_BATCH("85","手动发券"),
    //入会纪念日
    SEND_COUPON_MEMORY_DAY("90","入会纪念日"),
    //会员分组运营
    SEND_COUPON_MEMBER_GROUP("94","会员分组运营"),
    //智能营销
    SEND_COUPON_ORIENT_MARKET("95","智能营销"),
    //评价奖励活动
    SEND_COUPON_REIVEW("100","评价奖励活动"),
    //积分商城
    SEND_COUPON_INTEGRAL_MALl("101","积分商城"),
    //企业微信配额券
    SEND_COUPON_QUOTA_MALl("102","企业微信配额券"),
    //大转盘
    SEND_COUPON_ROTARRY("103","大转盘"),
    //红包膨胀
    SEND_COUPON_RED("104","红包膨胀"),
    //砸金蛋
    SEND_COUPON_EGGS("105","砸金蛋"),
    //宝宝生日活动
    SEND_COUPON_BABY_BIRTHDAY("106","宝宝生日活动"),
    //会员首单活动
    SEND_COUPON_FIRST_SINGLE("107","会员首单活动"),
    //摇一摇
    SEND_COUPON_SHAKE("108","摇一摇"),
    //储值送礼
    SEND_COUPON_GIFT("109","储值送礼"),

    //预生成券
    SEND_COUPON_PRE("110","预生成券"),
    //员工券
    SEND_COUPON_STAFF("111","员工券"),
    //线下ERP系统发券
    SEND_COUPON_FROM_ERP("115", "线下ERP系统发券"),
    //天猫发券
    SEND_COUPIN_TMALL("120", "天猫发券"),
    //线下发券
    SEND_COUPON_ERP_RECEIVE("125","线下发券"),
    //用户营销发放
    SEND_COUPON_GOLDLION_EQUITY("126","用户营销发放"),

    //开卡发券
	SEND_COUPON_OPNE_CARD("10","开卡发券"),

    //受邀开卡奖励优惠券
    SEND_COUPON_INVITEED_OPENCARD_TASK("79","受邀开卡奖励优惠券");

    private String code;
    private String message;
    SendTypeEnum(String code,String message){
        this.code = code;
        this.message = message;
    }

    public String getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

    public static String getValue(String code){
        for(SendTypeEnum ele :SendTypeEnum.values()){
            if(ele.getCode().equals(code)) {
                return ele.getMessage();
            }
        }
        return "无匹配券类型";
    }


}

==> coupon-facade-1.5.2-vg-20230207.114711-3-sources.jar: com/bizvane/couponfacade/enums/SendTypeEnum.java <==
package com.bizvane.couponfacade.enums;

/**
 * 券实例发放类型枚举类
 * Created by yunjie.tian on 2018/8/9.
 */
public enum SendTypeEnum {

    //会员生日
    SEND_COUPON_BIRTH("15","会员生日"),
    //受赠
    SEND_COUPON_GIVE("20","受赠"),
    //积分兑换
    SEND_COUPON_INTEGRAL("25","积分兑换"),
    //SEND_COUPON_ONLINE_ACTIVITY("30","线上开卡"),
    //会员升级
    SEND_COUPON_UPGRADE_ACTIVITY("35","会员升级"),
    //SEND_COUPON_BIRTH_ACTIVITY("40","会员生日"),
    //会员消费
    SEND_COUPON_COUSUME_ACTIVITY("45","会员消费"),
    //会员签到
    SEND_COUPON_SIGN_ACTIVITY("50","会员签到"),
    //领券
    SEND_COUPON_RECEIVE_ACTIVITY("55","领券"),
    //社交活动
    SEND_COUPON_SOCIAL_ACTIVITY ("56","社交活动"),
    //完善资料
    SEND_COUPON_INFORM_TASK("60","完善资料"),
    //微信分享
    SEND_COUPON_WX_SHARE_TASK("65","微信分享"),
    //消费次数
    SEND_COUPON_COUSUME_TIMES_TASK("70","消费次数"),
    //消费金额
    SEND_COUPON_COUSUME_MONEY_TASK("75","消费活动"),
    //邀请开卡
    SEND_COUPON_INVITE_OPENCARD_TASK("80","邀请开卡"),
    //调查问卷
    SEND_COUPON_QUESTIONNAIRE_TASK("81","调查问卷"),
    //手动发券
    SEND_COUPON_BATCH("85","手动发券"),
    //入会纪念日
    SEND_COUPON_MEMORY_DAY("90","入会纪念日"),
    //会员分组运营
    SEND_COUPON_MEMBER_GROUP("94","会员分组运营"),
    //智能营销
    SEND_COUPON_ORIENT_MARKET("95","智能营销"),
    //评价奖励活动
    SEND_COUPON_REIVEW("100","评价奖励活动"),
    //积分商城
    SEND_COUPON_INTEGRAL_MALl("101","积分商城"),
    //企业微信配额券
    SEND_COUPON_QUOTA_MALl("102","企业微信配额券"),
    //大转盘
    SEND_COUPON_ROTARRY("103","大转盘"),
    //红包膨胀
    SEND_COUPON_RED("104","红包膨胀"),
    //砸金蛋
    SEND_COUPON_EGGS("105","砸金蛋"),
    //宝宝生日活动
    SEND_COUPON_BABY_BIRTHDAY("106","宝宝生日活动"),
    //会员首单活动
    SEND_COUPON_FIRST_SINGLE("107","会员首单活动"),
    //摇一摇
    SEND_COUPON_SHAKE("108","摇一摇"),
    //储值送礼
    SEND_COUPON_GIFT("109","储值送礼"),

    //预生成券
    SEND_COUPON_PRE("110","预生成券"),
    //员工券
    SEND_COUPON_STAFF("111","员工券"),
    //线下ERP系统发券
    SEND_COUPON_FROM_ERP("115", "线下ERP系统发券"),
    //天猫发券
    SEND_COUPIN_TMALL("120", "天猫发券"),
    //线下发券
    SEND_COUPON_ERP_RECEIVE("125","线下发券"),
    //用户营销发放
    SEND_COUPON_GOLDLION_EQUITY("126","用户营销发放"),

    //开卡发券
	SEND_COUPON_OPNE_CARD("10","开卡发券"),

    //受邀开卡奖励优惠券
    SEND_COUPON_INVITEED_OPENCARD_TASK("79","受邀开卡奖励优惠券");

    private String code;
    private String message;
    SendTypeEnum(String code,String message){
        this.code = code;
        this.message = message;
    }

    public String getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

    public static String getValue(String code){
        for(SendTypeEnum ele :SendTypeEnum.values()){
            if(ele.getCode().equals(code)) {
                return ele.getMessage();
            }
        }
        return "无匹配券类型";
    }


}
